@@ -207,7 +207,7 @@ class Server(object):
             opaque, cas))
 
         if status != self.STATUS['success']:
-            raise MemcachedError('Code: %d Message: %s' % (status,
+            raise MemcachedException('Code: %d Message: %s' % (status,
                 self.connection.recv(bodylen)))
 
         return True
@@ -222,11 +222,16 @@ class Server(object):
 
         header = self.connection.recv(self.HEADER_SIZE)
 
+        # TODO: Why is this returning a string instead a real header?
+        if header == 'Not found':
+            return True
+
         (magic, opcode, keylen, extlen, datatype, status, bodylen,
             opaque, cas) = struct.unpack(self.HEADER_STRUCT, header)
 
-        if status != self.STATUS['success']:
-            raise MemcachedError('Code: %d Message: %s' % (status,
+        if status != self.STATUS['success'] \
+            and status != self.STATUS['key_not_found']:
+            raise MemcachedException('Code: %d Message: %s' % (status,
                 self.connection.recv(bodylen)))
 
         logger.debug('Key deleted %s' % key)
